RWP
===

A Pakistani language random word generator.


Details
-------

Uses a predefined set of words for enumeration.


Package Usage
-------------

from rwpk import rwpk

\# show a phrase made of n=2 random words

rwpk.show_random_words('urdu', 2)
